#!/bin/sh

. ${srcdir:=.}/t.frame

set -e

# Note:  This test DOES leave its output files on the hard drive.
#	 This makes it easier to see what has happened, which is
#		especially useful when something is different.
#
#        In directory t.systest.d are:
#
#		tests   - directory containing individual output files
#		grftest.out - comparison of directories:
#			      outputs - known correct outputs
#			      tests   - outputs of the individual tests

verbose=0
if [ "$1" = "-v" ]; then
    verbose=1
fi

[   -d ${TMPDIR} ] && rm -rf ${TMPDIR}/*
[ ! -d ${TMPDIR} ] && mkdir ${TMPDIR}

cat <<EOF > ${TMPDIR}/cfg.r
robx=0.415
min_dev=0.0
EOF

BOGOFILTER="../bogofilter"
SYSTEST="${srcdir}/t.systest.d"

map_rc()
{
    (
	set +e
	eval "$@"
	a=$?
	[ $a -eq 0 ] && exit 0
	[ $a -eq 1 ] && exit 0
	exit $a
    )
}

run_test()
{
    id="$1"
    out="$2"
    ver="$3"
    OUT="${TMPDIR}/tests/msg.$out.$alg.$ver"
    OPTS="-$alg -$ver -c ${TMPDIR}/cfg.$alg"
    map_rc $BOGOFILTER $OPTS <${SYSTEST}/inputs/msg.$id.txt >${TMPDIR}/tests-$alg 
    sed s/,.version=.*// < ${TMPDIR}/tests-$alg > $OUT
}

[   -d ${TMPDIR}/tests ] && rm -f ${TMPDIR}/tests/*
[ ! -d ${TMPDIR}/tests ] && mkdir -p ${TMPDIR}/tests

for alg in r ; do
    BOGOFILTER_DIR="${TMPDIR}/tests.$alg"
    export BOGOFILTER_DIR
    [   -d $BOGOFILTER_DIR ] && rm -f $BOGOFILTER_DIR/*
    [ ! -d $BOGOFILTER_DIR ] && mkdir $BOGOFILTER_DIR
    $BOGOFILTER -$alg -s < ${SYSTEST}/inputs/spam.mbx
    $BOGOFILTER -$alg -n < ${SYSTEST}/inputs/good.mbx
    #
    # run tests for msg.[1-8].txt
    #
    for msg in ${SYSTEST}/inputs/msg.?.txt ; do
	tst=`echo $msg | sed s@${SYSTEST}/inputs/msg.@@ | sed s@.txt@@`
	args="$tst $tst vvv"
	run_test $args
    done

    rm -f ${TMPDIR}/tests-$alg
done

pfx=$srcdir/t.systest.d/outputs
for i in $pfx/*v ; do
    # SunOS /bin/sh does not like ${i##$pfx/}
    j=`echo $i | sed "s'^$pfx/''"`
    cmp $i ${TMPDIR}/tests/$j
done
